@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.400020';
+$BalanceOfPower::Commands::VERSION = '0.400100';
 use v5.10;
 use Moo;
 use IO::Prompter [-stdio];
@@ -523,6 +523,12 @@ COMMANDS
         print $self->world->print_targets($self->get_active_player()->name);
         $result = { status => 1 };
     }
+    elsif($query =~ /^friends( (.*))?$/)
+    {
+        my $input_nation = $self->world->correct_nation_name($2);
+        print $self->get_active_player->print_friendship($input_nation);
+        $result = { status => 1 };
+    }
     else
     {
         my $nation_query = $self->world->correct_nation_name($query);
@@ -824,9 +830,14 @@ sub shop_commands
             $result = { status => $res };
         }
     }
-    elsif($query =~ /^ssell +([0-9]+) +(.*)$/)
+    elsif($query =~ /^ssell +([0-9]+) +(.*?)( +(bm))?$/)
     {
-        my ($res, $cost) = $self->world->do_transaction($self->get_active_player, 'sell', $1, $2);
+        my $flags = {};
+        if($4 && $4 eq 'bm')
+        {
+            $flags->{'bm'} = 1;   
+        }
+        my ($res, $cost) = $self->world->do_transaction($self->get_active_player, 'sell', $1, $2, $flags);
         if($res == 1)
         {
             $result = { status => 30, cost => $cost};
@@ -868,18 +879,18 @@ sub commands
         $self->latest_result($result);
         return 1;
     }
-    $result = $self->travel_commands();
-    if($self->handle_result('travel', $result))
-    {
-        $self->latest_result($result);
-        return 1;
-    }
-    $result = $self->shop_commands();
-    if($self->handle_result('shop', $result))
-    {
-        $self->latest_result($result);
-        return 1;
-    }
+    #$result = $self->travel_commands();
+    #if($self->handle_result('travel', $result))
+    #{
+    #    $self->latest_result($result);
+    #    return 1;
+    #}
+    #$result = $self->shop_commands();
+    #if($self->handle_result('shop', $result))
+    #{
+    #    $self->latest_result($result);
+    #    return 1;
+    #}
     $result = $self->orders();
     if($self->handle_result('orders', $result))
     {
@@ -1098,7 +1109,11 @@ sub handle_result
     }
     elsif($type eq 'shop')
     {
-        if($result->{status} == 20)
+        if($result->{status} == 1)
+        {
+            return 1;
+        }
+        elsif($result->{status} == 20)
         {
             say "Transaction completed. Payed: " . $result->{cost};
             return 1;
@@ -1133,6 +1148,11 @@ sub handle_result
             say "You don't owe that quantity";
             return 1;
         }
+        if($result->{status} == -14)
+        {
+            say "You can't trade. This nation hates you!";
+            return 1;
+        }
         else
         {
             return 0;
