@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Shopper;
-$BalanceOfPower::Role::Shopper::VERSION = '0.400020';
+$BalanceOfPower::Role::Shopper::VERSION = '0.400100';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -14,6 +14,36 @@ requires 'get_statistics_value';
 
 
 my @products = ( 'goods', 'luxury', 'arms', 'tech', 'culture' );
+my %dependencies = ( 'goods' => 'p/d',
+                     'luxury' => 'w/d', 
+                     'arms' => 'army',
+                     'tech' => 'progress',
+                     'culture' => 'prestige' );
+
+sub get_stat_for_price
+{
+    my $self = shift;
+    my $y = shift;
+    my $type = shift;
+    my $nation = shift; #Max value if null
+    my $turn = $type eq 'goods' || $type eq 'prestige' ? $y : prev_turn($y);
+    if(! $nation)
+    {
+        my @stat_values = $self->order_statistics($turn, $dependencies{$type});
+        if(@stat_values == 0)
+        {
+            return 0;
+        }
+        else
+        {
+            return $stat_values[0]->{'value'};
+        }
+    }
+    else
+    {
+        return $self->get_statistics_value($turn, $nation, $dependencies{$type});
+    }
+}
 
 sub calculate_price
 {
@@ -22,27 +52,16 @@ sub calculate_price
     my $type = shift;
     my $nation = shift;
 
-
-    my %dependencies = ( 'goods' => 'p/d',
-                          'luxury' => 'w/d', 
-                          'arms' => 'army',
-                          'tech' => 'progress',
-                          'culture' => 'prestige' );
-
     #Price formula is MaxPrice - (( MaxPrice - MinPrice) / MaxValue) * Value
     #MaxPrice and MinPrice are constant
 
-    my $turn = $type eq 'goods' || $type eq 'prestige' ? $y : prev_turn($y);
-
     my $min_price = PRICE_RANGES->{$type}->[0];
     my $max_price = PRICE_RANGES->{$type}->[1];
 
-    my @stat_values = $self->order_statistics($turn, $dependencies{$type});
-    return SHOP_PRICE_FACTOR if(@stat_values == 0);
+    my $max_value = $self->get_stat_for_price($y, $type);
+    return SHOP_PRICE_FACTOR if($max_value == 0);
 
-    my $max_value = $stat_values[0]->{'value'};
-
-    my $value = $self->get_statistics_value($turn, $nation, $dependencies{$type});
+    my $value =  $self->get_stat_for_price($y, $type, $nation);
 
     return int(((($max_price - (($max_price - $min_price) / $max_value) * $value))* SHOP_PRICE_FACTOR)*100)/100;
 }
@@ -55,8 +74,9 @@ sub get_all_nation_prices
     my %data = ();
     foreach my $p (@products)
     {
-        my $label = $p . "_price";
-        $data{$label} = $self->calculate_price($year, $p, $nation);
+        my $price = $self->calculate_price($year, $p, $nation);
+        my $stat = $self->get_stat_for_price($year, $p, $nation);
+        $data{$p} = { price => $price, stat => $stat };
     }
     return %data;
 }
@@ -89,6 +109,8 @@ sub print_all_nations_prices
                                                   names => \@nations }); 
 }
 
+
+
 sub do_transaction
 {
     my $self = shift;
@@ -96,11 +118,17 @@ sub do_transaction
     my $action = shift;
     my $q = shift;
     my $what = shift;
+    my $flags = shift;
     if(! grep {$_ eq $what} @products)
     {
         return -10;
     }
+    if($player->get_friendship($player->position) < FRIENDSHIP_LIMIT_TO_SHOP)
+    {
+        return -14;
+    }
     my $price = $self->calculate_price($self->current_year, $what, $player->position);
+    my $stat = $self->get_stat_for_price($self->current_year, $what, $player->position);
     my $cost = $price * $q;
     if($action eq 'buy')
     {   
@@ -113,7 +141,7 @@ sub do_transaction
             return -12;
         }
         $player->add_money(-1 * $cost);
-        $player->add_cargo($what, $q);
+        $player->add_cargo($what, $q, $cost, $stat);
     }
     elsif($action eq 'sell')
     {
@@ -122,8 +150,18 @@ sub do_transaction
         {
             return -13;
         }
-        $player->add_money($cost);
-        $player->add_cargo($what, -1 * $q);
+        if(exists $flags->{'bm'})
+        {
+            $cost = $cost + (BLACK_MARKET_PERCENT_SELLING_BONUS * $cost) / 100;
+            $player->add_money($cost);
+            $player->add_cargo($what, -1 * $q, $cost, $stat);
+            $player->add_friendship($player->position, BLACK_MARKET_FRIENDSHIP_MALUS);
+        }
+        else
+        {
+            $player->add_money($cost);
+            $player->add_cargo($what, -1 * $q, $cost, $stat);
+        }
     }
     return (1, $cost);
 }
